@@ -9,22 +9,21 @@
 
 import sys
 
-from Globals import package_home
-
 from Products.CMFCore import utils as CMFutils
 from Products.CMFCore.DirectoryView import registerDirectory
 
 from Products.Archetypes.public import process_types, listTypes
 
-from config import SKINS_DIR, GLOBALS, PROJECTNAME
+from config import SKINS_DIR, PROJECTNAME
 from config import ADD_CONTENT_PERMISSION, ENTRY_TYPES
 
 import content
-from tool import bibliography, parsers, renderers
+from tool import bibliography, idcookers
 
 tools = ( bibliography.BibliographyTool, )
 
-registerDirectory(SKINS_DIR, GLOBALS)
+GLOBALS = globals()
+registerDirectory('skins', GLOBALS)
 
 def initialize(context):
     content_types, constructors, ftis = process_types(
@@ -40,11 +39,9 @@ def initialize(context):
     CMFutils.ToolInit(
         'Bibliography Tool',
         tools=tools,
-        ## product_name=PROJECTNAME,
         icon='bibliography_tool.png',
         ).initialize(context)
-    parsers.initialize(context)
-    renderers.initialize(context)
+    idcookers.initialize(context)
 
 # module aliases for backward compatibility
 
@@ -80,32 +77,17 @@ sys.modules[old_path + 'WebpublishedReference'] = webpublished
 
 from tool import bibliography
 sys.modules['Products.CMFBibliographyAT.BibliographyTool'] = bibliography
-from tool.parsers import base
-sys.modules['Products.CMFBibliographyAT.BibliographyParser'] = base
-from tool.renderers import base
-sys.modules['Products.CMFBibliographyAT.BibliographyRenderer'] = base
 
-from tool import parsers
-sys.modules['Products.CMFBibliographyAT.parsers'] = parsers
-old_path = 'Products.CMFBibliographyAT.parsers.'
-from tool.parsers import bibtex, endnote, ibss, isbn, medline, pyblbibtex, \
-     ris, xml
-sys.modules[old_path + 'BibtexParser'] = bibtex
-sys.modules[old_path + 'EndNoteParser'] = endnote
-sys.modules[old_path + 'IBSSParser'] = ibss
-sys.modules[old_path + 'ISBNParser'] = isbn
-sys.modules[old_path + 'MedlineParser'] = medline
-sys.modules[old_path + 'PyBlBibtexParser'] = pyblbibtex
-sys.modules[old_path + 'RISParser'] = ris
-sys.modules[old_path + 'XMLParser'] = xml
+# check Bibutils version
+from bibliograph.core.version_check import checkBibutilsVersion
+import logging
+LOG = logging.getLogger('Products.CMFBibliographyAT')
+
+try:
+    bibutils_version = checkBibutilsVersion()
+    LOG.info('Installed Bibutils version: %s' % bibutils_version)
+except RuntimeError, e:
+    bibutils_version = None
+    LOG.warn(e)
 
-from tool import renderers
-sys.modules['Products.CMFBibliographyAT.renderers'] = renderers
-old_path = 'Products.CMFBibliographyAT.renderers.'
-from tool.renderers import bibtex, endnote, pdf, ris, xml
-sys.modules[old_path + 'BibtexRenderer'] = bibtex
-sys.modules[old_path + 'EndRenderer'] = endnote
-sys.modules[old_path + 'PDFRenderer'] = pdf
-sys.modules[old_path + 'RISRenderer'] = ris
-sys.modules[old_path + 'XMLRenderer'] = xml
 
